@@ -27,7 +27,7 @@ static   int pictureX=300;
 static   int pictureY=200;
 static   char  letterSize[14]="normalsize";
 
-static int  logScale=1;
+static int  logY=1;
 static int  fgcolor = FGmain,  bkcolor = BGmain; 
 
                            
@@ -48,7 +48,7 @@ static void axisDesign(double xmin,double xmax, int islog,
   { 
     n=1+log10(xmax/xmin)/10;
     *step=pow((double)10,(double)n);     
-    *xfirst=pow((double)10,(double)nlog10(xmin));
+    *xfirst=pow(10, nlog10(xmin));
     *nsub=9; 
   }else
   {      
@@ -98,6 +98,8 @@ static void  gminmax(double *f ,double * df,int dim, double *ymin,double*ymax)
    { *ymin=MIN(*ymin, f[i]); 
      *ymax=MAX(*ymax, f[i]);
    } 
+   double z=(*ymax-*ymin)/50;
+   *ymax+=z;
 }
 
 
@@ -111,7 +113,7 @@ static int scx(double  x)
 
 static int  scy(double  x)
 {  
-   if (logScale)   x = log10(x / grafminmax.ymin); 
+   if (logY)   x = log10(x / grafminmax.ymin); 
    else            x -= grafminmax.ymin; 
    return Y1 - chpround(yscale * x);
 } 
@@ -126,7 +128,7 @@ static double  dscx(double x)
 
 static double  dscy(double  x)
 { 
-   if (logScale) 
+   if (logY) 
    {  
      if(x>0)  x = log10(x / grafminmax.ymin);
      else     x=   -10000*log10(grafminmax.ymax/grafminmax.ymin) ;
@@ -142,7 +144,7 @@ static double xPhys(void)
 }
 
 static double yPhys(void)
-{  if(logScale)
+{  if(logY)
    return pow(10,(Y1-mouse_info.y)/yscale)*grafminmax.ymin;  
    else   return -(mouse_info.y -Y1)/yscale + grafminmax.ymin;
 }
@@ -203,7 +205,7 @@ static void  gaxes(char* upstr, char* xstr, int N, char**Y)
    grafminmax.ymin = ymin; 
    grafminmax.ymax = ymax; 
   
-   if (logScale && ( ymin <= 0.0 || log10(ymax/ymin)<1 )) logScale=0;
+   if (logY && ( ymin <= 0.0 || log10(ymax/ymin)<1 )) logY=0;
 
    tg_setlinestyle(SolidLn,NormWidth);
 
@@ -211,7 +213,7 @@ static void  gaxes(char* upstr, char* xstr, int N, char**Y)
    Y1 = tg_getmaxy() - 5*th; Y2 = 5*th/2; 
 
    xscale = (X2 - X1) / ( logX    ? log10(xmax/xmin) :  xmax - xmin);
-   yscale = (Y1 - Y2) / (logScale ? log10(ymax/ymin) :  ymax - ymin); 
+   yscale = (Y1 - Y2) / (logY ? log10(ymax/ymin) :  ymax - ymin); 
 
    tg_settextjustify(CenterText,TopText);
    tg_outtextxy((X1+X2)/2,CenterText,upstr);  
@@ -234,15 +236,22 @@ static void  gaxes(char* upstr, char* xstr, int N, char**Y)
      } else
      { 
         xy='Y';
-        islog = logScale; 
+        islog = logY; 
         tg_settextjustify(RightText,CenterText);
         zmin=ymin;
         zmax=ymax;
         xend=X1;
         yend=Y2;              
      }
-     zmax1 = zmax + fabs(zmax-zmin)*1.E-4;
-     zmin1 = zmin - fabs(zmax-zmin)*1.E-4;
+     if(islog)
+     {
+       zmax1 = zmax*(1+1E-4*log(zmax/zmin));
+       zmin1 = zmin/(1+1E-4*log(zmax/zmin));
+     } else
+     { 
+       zmax1 = zmax + fabs(zmax-zmin)*1.E-4;
+       zmin1 = zmin - fabs(zmax-zmin)*1.E-4;
+     }  
      axisDesign(zmin,zmax, islog,&aa, &step,&n_sub);
 
      tg_line(X1,Y1,xend,yend);
@@ -297,7 +306,6 @@ static void plot_curve(double xMin,double xMax,int dim, double *f)
    double step= logX? pow(xMax/xMin,1./dim) : (xMax-xMin)/dim;
    double ymax = dscy(grafminmax.ymin);
    double ymin = dscy(grafminmax.ymax);
-   
    for(i=1;i<dim;i++)
    {
       if(logX)
@@ -327,7 +335,7 @@ static void plot_curve(double xMin,double xMax,int dim, double *f)
       
 }
 
-static void plot_spline(double xMin,double xMax,int dim, int lScale, double *f)
+static void plot_spline(double xMin,double xMax,int dim, double *f)
 {  double   x,y,xx,yy;
    int i;
    double step=(xMax-xMin)/dim;
@@ -335,15 +343,23 @@ static void plot_spline(double xMin,double xMax,int dim, int lScale, double *f)
    double ymin = dscy(grafminmax.ymax);
    double xgrid[300];
    double sdim=300;
+
+   double * fLn;
+   if(logY)
+   { fLn=malloc(dim*sizeof(double));
+     for(i=0;i<dim;i++) fLn[i]=log(f[i]);
+   }       
+
+
    
-   if(lScale)for(i=0;i<dim;i++) xgrid[i]=xMin*pow(xMax/xMin, (i+0.5)/(double)dim);
+   if(logX)for(i=0;i<dim;i++) xgrid[i]=log(xMin*pow(xMax/xMin, (i+0.5)/(double)dim));
    else      for(i=0;i<dim;i++) xgrid[i]=xMin+(i+0.5)*step; 
 
    step=(xMax-xMin)/sdim;
           
    for(i=1;i<sdim;i++)
    {  double x1,x2;
-      if(lScale)
+      if(logX)
       { x1=xMin*pow(xMax/xMin,(i+0.5)/sdim);
         x2=xMin*pow(xMax/xMin,(i+1.5)/sdim);
       } else  
@@ -352,8 +368,22 @@ static void plot_spline(double xMin,double xMax,int dim, int lScale, double *f)
       }  
       x =dscx(x1);
       xx=dscx(x2); 
-      y =dscy(polint3(x1,dim,xgrid,f));
-      yy=dscy(polint3(x2,dim,xgrid,f));
+      if(logX) { x1=log(x1);x2=log(x2);}
+      if(logY)
+      { y =exp(polint3(x1,dim,xgrid,fLn));
+        if( !isfinite(y)) y =exp(polint1(x1,dim,xgrid,fLn));
+        if( !isfinite(y)) y = polint3(x1,dim,xgrid,f);
+
+        yy=exp(polint3(x2,dim,xgrid,fLn));
+        if( !isfinite(yy)) yy =exp(polint1(x2,dim,xgrid,fLn));
+        if( !isfinite(yy)) yy = polint3(x2,dim,xgrid,f);
+      } else 
+      {  
+        y =polint3(x1,dim,xgrid,f);
+        yy=polint3(x2,dim,xgrid,f);
+      }  
+      y  = dscy(y);
+      yy = dscy(yy);
       if ( yy < y) 
       { double z;
         z=yy;yy=y;y=z;
@@ -366,13 +396,14 @@ static void plot_spline(double xMin,double xMax,int dim, int lScale, double *f)
         if(y<ymin) {  x=  x-((x-xx)*(y -ymin))/(y-yy); y=ymin;}
         tg_line((int)x,(int)y,(int)xx,(int)yy);
       }
-   }      
+   }
+   if(logY) free(fLn);      
 }
 
 
 
 static void plot_hist(double xMin,double xMax,int dim, double *f,double *df)
-{  double   x,y,yy;
+{  double   x,y,yp,ym;
    int i;
 
    double ymax = dscy(grafminmax.ymin);
@@ -382,17 +413,24 @@ static void plot_hist(double xMin,double xMax,int dim, double *f,double *df)
    for(i=0;i<dim;i++)
    {  
      y =dscy(f[i]);
-     if(y<ymax && y>ymin) tg_line((int)dscx(xMin+i*step),  (int)y,
-                                    (int)dscx(xMin+(i+1)*step),(int)y);
-     y =MIN(dscy(f[i]-df[i]),ymax);
-     yy=MAX(dscy(f[i]+df[i]),ymin);
-     x=(dscx(xMin+i*step)+dscx(xMin+(i+1)*step))/2;
-     if(y>yy) tg_line((int)x,(int)y, (int)x,(int)yy );        
+     yp=MAX(dscy(f[i]+df[i]),ymin);
+     ym=MIN(dscy(f[i]-df[i]),ymax); 
+     if(y<ymax && y>ymin)
+     { if(logX)
+       {  tg_line((int)dscx(xMin*pow(xMax/xMin,(double)i/dim)),  (int)y, (int)dscx(xMin*pow(xMax/xMin,(double)(i+1)/dim)),(int)y);
+          x=dscx(xMin*pow(xMax/xMin,(i+0.5)/dim));
+       }   
+       else
+       {  tg_line((int)dscx(xMin+i*step),  (int)y, (int)dscx(xMin+(i+1)*step),(int)y);
+          x=dscx(xMin+(i+0.5)*step);
+       } 
+       if(yp<ym) tg_line((int)x,(int)ym, (int)x,(int)yp );  
+     }  
    }
 }
 
 
-static int writetable1(char * filename, double xMin,double xMax, double yMin, double yMax, int logScale, 
+static int writetable1(char * filename, double xMin,double xMax, double yMin, double yMax,
      char*x_str,char*upstr, 
  int N, int*Dim, double**f,double**df,char**Y)  
 { 
@@ -448,7 +486,7 @@ static int writetable1(char * filename, double xMin,double xMax, double yMin, do
    return 0;
 }
 
-static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double yMax, int logScale, 
+static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double yMax, 
      char*x_str,char*upstr,  int N, int*Dim, char* type,char**Y)  
 {  char       filename[100], buff[STRSIZ],command[100];
    FILE *     outfile;
@@ -475,7 +513,7 @@ static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double y
    fprintf(outfile," yMax=%E\n",yMax);
 
    
-   if(logScale)  fprintf(outfile," set logscale y\n");
+   if(logY)  fprintf(outfile," set logscale y\n");
    if(logX)
    {  fprintf(outfile," set logscale x\n");
       for(k=0;k<N;k++) fprintf(outfile," X%d(n)=xMin*(xMax/xMin)**((n+0.5)/%d)\n",k,Dim[k]);
@@ -510,7 +548,7 @@ static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double y
 
 
 
-static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double yMax, int logScale, 
+static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double yMax,
      char*x_str,char*upstr, 
  int N, int*Dim, char*type,char**Y)  
 {  char       filename[100], buff[STRSIZ],command[100];
@@ -536,7 +574,7 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
    fprintf(outfile,"*  http://paw.web.cern.ch/paw/allfaqs.html\n");
    fprintf(outfile," opt zfl\n");
    fprintf(outfile,"set *FON -60\n");
-   if(logScale)  fprintf(outfile,"opt  logy\n");
+   if(logY)  fprintf(outfile,"opt  logy\n");
    if(logX) fprintf(outfile,"opt  logx\n");   
    fprintf(outfile,"* TITLE '%s'\n",upstr);
 
@@ -546,9 +584,18 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
    {  
      fprintf(outfile," vector/Create X%d(%d)  \n",k+1,Dim[k]);
      if(logX)
-     {
-       fprintf(outfile," sigma X%d=ARRAY(%d,0#%d)\n",k+1,Dim[k],Dim[k]-1);
-       fprintf(outfile," sigma X%d=%E*(%E)**((0.5+X%d)/%d)\n",k+1,xMin,xMax/xMin,k+1,Dim[k]);
+     { if(type[k]=='h')
+       { 
+          fprintf(outfile," sigma X%d=ARRAY(%d,0#%d)\n",k+1,Dim[k]+1,Dim[k]);
+          fprintf(outfile," sigma X%d=%E*(%E)**(X%d/%d)\n",k+1,xMin,xMax/xMin,k+1,Dim[k]);
+       }else 
+       {
+          fprintf(outfile," sigma X%d=ARRAY(%d,0#%d)\n",k+1,Dim[k],Dim[k]-1);
+          fprintf(outfile," sigma X%d=%E*(%E)**((0.5+X%d)/%d)\n",k+1,xMin,xMax/xMin,k+1,Dim[k]);
+       
+       
+       }
+          
      }
      else fprintf(outfile," sigma X%d=ARRAY(%d,%G#%G)\n",k+1,Dim[k],xMin+0.5*(xMax-xMin)/Dim[k],xMax-0.5*(xMax-xMin)/Dim[k]);
      
@@ -577,7 +624,7 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
      if(type[k]=='h' ) fprintf(outfile," set HCOL %d\n",k+1); 
      fprintf(outfile," set plci %i ; set txci %i  \n",k+1,k+1);
      
-     if(logScale) yl=exp(log(yMax)-0.05*(k+1)*log(yMax/yMin));
+     if(logY) yl=exp(log(yMax)-0.05*(k+1)*log(yMax/yMin));
      else  yl=yMax -0.05*(k+1)*(yMax-yMin);
              
      
@@ -587,8 +634,12 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
      if(type[k]=='h')
      {
        fprintf(outfile," set dmod 1\n");
-       fprintf(outfile," histogram/create/1dhisto %d '%s' %d %G %G\n",
-                         k+1,upstr,Dim[k],xMin,xMax);                
+       if(logX)
+           fprintf(outfile," histogram/create/bins %d '%s' %d  X%d\n",
+                         k+1,upstr,Dim[k],k+1);  
+       else 
+           fprintf(outfile," histogram/create/1dhisto %d '%s' %d %G %G\n",
+                         k+1,upstr,Dim[k],xMin,xMax);  
        fprintf(outfile," histogram/put/contents %d Y%d\n",k+1,k+1);
        fprintf(outfile," histogram/put/errors   %d dY%d\n",k+1,k+1);   
        fprintf(outfile," histogram/plot %d  s\n",k+1);
@@ -612,7 +663,7 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
 }
 
 
-static void  writeROOT(char *fname,  double xMin,double xMax, double yMin, double yMax, int logScale, 
+static void  writeROOT(char *fname,  double xMin,double xMax, double yMin, double yMax, 
      char*x_str,char*upstr, int N, int*Dim, char*type,char**Y)  
 {  char       filename[100],basename[100], buff[STRSIZ];
    FILE *     outfile;
@@ -654,7 +705,7 @@ fprintf(outfile,
    if(logX)
    { 
         fprintf(outfile," Can->SetLogx();\n");
-        for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin*pow(xMax/xMin,(i+0.5)/%d);dX%d[i]=X%d[i]*(1-pow(xMax/xMin,0.333/%d));} \n", Dim[k],k,Dim[k],k,k,Dim[k]);    
+        for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin*pow(xMax/xMin,(i+0.5)/%d);dX%d[i]=X%d[i]*(pow(xMax/xMin,0.333/%d)-1);} \n", Dim[k],k,Dim[k],k,k,Dim[k]);    
    } 
    else for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin+(i+0.5)*(xMax-xMin)/%d; dX%d[i]=(xMax-xMin)/3./%d;}\n", Dim[k],k,Dim[k],k,Dim[k]);
          
@@ -663,7 +714,7 @@ fprintf(outfile,
    else    fprintf(outfile," double Xtext = xMin+0.3*(xMax-xMin);\n");  
    fprintf(outfile," double Ytext= yMax;\n");
 
-   if(logScale)   
+   if(logY)   
    {
      fprintf(outfile," Can->SetLogy();\n");
      fprintf(outfile," double dYtext=pow(yMax/yMin,0.055);\n");
@@ -706,19 +757,19 @@ fprintf(outfile,
            
    for(k=0;k<N;k++)
    { if(type[k]=='h') 
-     {  fprintf(outfile,"   TGraphErrors *gr%d =new TGraphErrors(%d,X,Y%d,dX%d,dY%d);\n",k,Dim[k],k,k,k);
-        fprintf(outfile,"   gr%d->SetLineColor(%d);\n",k,k); 
+     {  fprintf(outfile,"   TGraphErrors *gr%d =new TGraphErrors(%d,X%d,Y%d,dX%d,dY%d);\n",k,Dim[k],k,k,k,k);
+        fprintf(outfile,"   gr%d->SetLineColor(%d);\n",k,k+1); 
         fprintf(outfile,"   gr%d->Draw(\"P\");\n",k);
      } else 
      {   
        fprintf(outfile, "   TGraph *gr%d = new TGraph (%d,X%d,Y%d);\n",k,Dim[k],k,k); 
        fprintf(outfile, "   gr%d->SetLineColor(%d);\n",k,k+1);
-       if(type[k-1]=='l') fprintf(outfile, "   gr%d->Draw(\"L\");\n",k);
+       if(type[k]=='l') fprintf(outfile, "   gr%d->Draw(\"L\");\n",k);
        else fprintf(outfile, "   gr%d->Draw(\"C\");\n",k);
      }
      if(N>1 && Y[k][0])
      {
-        if(logScale) fprintf(outfile,"   Ytext/=dYtext;\n"); else  fprintf(outfile,"  Ytext-=dYtext;\n");
+        if(logY) fprintf(outfile,"   Ytext/=dYtext;\n"); else  fprintf(outfile,"  Ytext-=dYtext;\n");
 /*
         fprintf(outfile,"  TText *t%d = new TText(Xtext,Ytext,\"%s\");\n",k,Y[k]);
         fprintf(outfile,"  t%d->SetTextColor(%d);\n",k,k+1);
@@ -738,6 +789,232 @@ fprintf(outfile,
    messanykey(10,12,filename);
 }
 
+static void  writePython(char *fname,  double xMin,double xMax, double yMin, double yMax,
+     char*x_str, char*upstr, int N, int*Dim, char*type, char**Y)  
+{  char       filename[100],basename[100], buff[STRSIZ];
+   FILE *     outfile;
+   int        i,k;
+   char  format[150]={}, read[150]={};   
+   
+   strcpy(basename,fname);
+
+   for(i=strlen(basename)-1; i>=0;i--) if(basename[i]=='.') { basename[i]=0; break; }
+   sprintf(filename,"%s.py",basename);
+   
+   outfile=fopen(filename,"w");
+   fprintf(outfile,          
+     "import os\n"
+     "import matplotlib.pyplot as plt\n"
+     "import numpy as np\n"
+     "from math import exp, log, sqrt\n"
+     "from scipy import interpolate\n");
+   
+      
+   
+   fprintf(outfile,"#--------------- data input -----------------------#\n");
+   format[0]=0;
+   for(k=0;k<N;k++) 
+   { if(k) fprintf(outfile,", "); 
+     fprintf(outfile,"y%d",k);
+     if(type[k]=='h') fprintf(outfile,", dy%d",k);
+   } 
+   fprintf(outfile," = np.genfromtxt('%s',dtype=float, comments='#',unpack=True)\n",fname);  
+    
+   fprintf(outfile,"#--------------- writing plots -----------------#\n");
+   fprintf(outfile,"#fig, ax = plt.subplots(figsize=(6,3.8))\n");
+   fprintf(outfile,"#plt.subplots_adjust(bottom=0.20,right=0.75,left=0.15)\n");
+
+   fprintf(outfile,"plt.title('%s')\n", upstr);
+   fprintf(outfile,"plt.xlabel('%s',fontsize=16)\n", x_str);
+   if(N==1) fprintf(outfile,"plt.ylabel('%s',fontsize=16)\n", Y[0]);
+   if(logX) fprintf(outfile,"plt.xscale('log')\n");    else fprintf(outfile,"plt.xscale('linear')\n"); 
+   if(logY)fprintf(outfile,"plt.yscale('log')\n"); else fprintf(outfile,"plt.yscale('linear')\n");
+   fprintf(outfile,"xmin=%E\n",xMin);
+   fprintf(outfile,"xmax=%E\n",xMax); 
+   fprintf(outfile,"plt.xlim(xmin,xmax)\n");
+   fprintf(outfile,"plt.ylim(%E,%E)\n",yMin,yMax);
+   for(k=0;k<N;k++) if(type[k]=='s') break;
+   if(k!=N) // interpalation is needed
+   { if(logX)
+     { fprintf(outfile,"li=np.linspace(log(xmin), log(xmax),300)\n");
+       fprintf(outfile,"xi=np.exp(li)\n");
+     }
+     else     fprintf(outfile,"xi=np.linspace(xmin, xmax,300)\n");
+   }
+   for(k=0;k<N;k++)
+   { if(logX) 
+     {  
+       fprintf(outfile,"xfirst=xmin*pow(xmax/xmin,0.5/%d)\n",Dim[k]); 
+       fprintf(outfile,"xlast=xmax/pow(xmax/xmin,0.5/%d)\n",Dim[k]);
+       fprintf(outfile,"l%d=np.linspace(log(xfirst),log(xlast),%d)\n",k,Dim[k]);
+       fprintf(outfile,"x%d=np.exp(l%d)\n",k,k);
+     }else 
+     {   
+       fprintf(outfile,"xfirst=xmin+0.5*(xmax-xmin)/%d\n",Dim[k]);
+       fprintf(outfile,"xlast=xmax -0.5*(xmax-xmin)/%d\n",Dim[k]);  
+       fprintf(outfile,"x%d=np.linspace(xfirst,xlast,%d)\n",k,Dim[k]);   
+     }
+     if(type[k]=='h')
+     { if(logX)
+       { fprintf(outfile,"c=sqrt(x%d[1]/x%d[0])\n",k,k);
+         fprintf(outfile,"errL=x%d*(1-1/c)\n",k);
+         fprintf(outfile,"errR=x%d*(c-1)\n",k); 
+         fprintf(outfile,"plt.errorbar(x%d, y%d[0:%d], dy%d[0:%d], xerr=[errL,errR], fmt=None,label='%s')\n",k,k,Dim[k],k,Dim[k],Y[k]);
+       }
+       else     fprintf(outfile,"plt.errorbar(x%d, y%d[0:%d], dy%d[0:%d], xerr=%e, fmt=None,label='%s')\n",k,k,Dim[k],k,Dim[k],0.45*(xMax-xMin)/Dim[k],Y[k]);
+     }else  if(type[k]=='s') // interpolation  
+     { 
+       if(logY) 
+       {  double Y_=yMin*sqrt(yMin/yMax);
+          fprintf(outfile,"for i in xrange(%d):\n",Dim[k]);
+          fprintf(outfile,"  if y%d[i] < %.1E:\n",k,Y_);
+          fprintf(outfile,"     y%d[i]=%.1E\n",k,Y_);
+       }
+       if(logX)
+       { if(logY)
+         {
+           fprintf(outfile,"tck=interpolate.splrep(l%d, np.log(y%d[0:%d]),s=0)\n",k,k,Dim[k]);
+           fprintf(outfile,"plt.plot(xi, np.exp(interpolate.splev(li, tck, der=0)), alpha=0.7, label='%s', linestyle='-')\n",Y[k]);   
+         }else
+         {  
+           fprintf(outfile,"tck=interpolate.splrep(l%d, y%d[0:%d],s=0)\n",k,k,Dim[k]);
+           fprintf(outfile,"plt.plot(xi, interpolate.splev(li, tck, der=0), alpha=0.7, label='%s', linestyle='-')\n",Y[k]);
+         }
+       }else
+       { if(logY)
+         { fprintf(outfile,"tck=interpolate.splrep(x%d, np.log(y%d[0:%d]),s=0)\n",k,k);
+           fprintf(outfile,"plt.plot(xi, np.exp(interpolate.splev(xi, tck, der=0)), alpha=0.7, label='%s', linestyle='-')\n",Y[k]); 
+         } else 
+         {
+           fprintf(outfile,"tck=interpolate.splrep(x%d, y%d[0:%d],s=0)\n",k,k);
+           fprintf(outfile,"plt.plot(xi, interpolate.splev(xi, tck, der=0), alpha=0.7, label='%s', linestyle='-')\n",Y[k]);
+         }  
+       }
+     } 
+     else fprintf(outfile,"plt.plot(x%d, y%d[0:%d],alpha=0.7, label='%s', linestyle='-')\n",k,k,Dim[k],Y[k]);
+/*
+        else if(type[k]=='s') // interpolation 
+        {  fprintf("fi = interpolate.interp1d(x%d, y%d)\n");
+           fprintf(outfile,"dxi=dx*%d/300\n",Dim[k]); // to use 300 points  
+           if(logX) 
+           { fprintf(outfile,"lx=np.linspace(log(xmin)+dxi, log(xmax)-dxi,%d)\n",300);
+             fprintf(outfile,"xi=np.exp(lx)\n");    
+           } else fprintf(outfile,"xi=np.linspace(xmin+dx, xmax-dx,%d)\n",300);
+           fprintf(outfile,"plt.plot(xi, fi(xi),alpha=0.7, label='%s', linestyle='-')\n",Y[k]);
+        }   
+     
+        if(N>1) fprintf(outfile,"plt.plot(x%d, y%d[0:%d],alpha=0.7, label='%s', linestyle='-')\n",k,k,Dim[k],Y[k]); 
+        else    fprintf(outfile,"plt.plot(x%d, y%d[0:%d],alpha=0.7, linestyle='-')\n",k,k,Dim[k],Y[k]);
+     }
+*/     
+   }
+   if(N>1) fprintf(outfile,"plt.legend()\n");
+   fprintf(outfile,"plt.savefig('%s.pdf')\n", basename);
+   fprintf(outfile,"plt.show()\n"); 
+        
+#ifdef UseDeleted 
+    
+   for(i=strlen(basename)-1; i>=0 && basename[i]!='/';i--);
+   if(i<0) i=0;
+   fprintf(outfile,"void %s(void)\n{\n",basename+i);
+   
+   fprintf(outfile," TCanvas *Can = new TCanvas(\"c\",\"%s\",200,10,600,400);\n",upstr);
+   fprintf(outfile," double xMin=%E, xMax=%E, yMin=%E, yMax=%E;\n",xMin,xMax,yMin,yMax);
+   fprintf(outfile," char buff[2000];\n");
+   fprintf(outfile," double "); 
+   for(k=0;k<N;k++){ fprintf(outfile," X%d[%d],dX%d[%d]",k,Dim[k],k,Dim[k]); 
+                     if(k<N-1) fprintf(outfile,","); else  fprintf(outfile,";\n");
+                   }           
+   if(logX)
+   { 
+        fprintf(outfile," Can->SetLogx();\n");
+        for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin*pow(xMax/xMin,(i+0.5)/%d);dX%d[i]=X%d[i]*(pow(xMax/xMin,0.333/%d)-1);} \n", Dim[k],k,Dim[k],k,k,Dim[k]);    
+   } 
+   else for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin+(i+0.5)*(xMax-xMin)/%d; dX%d[i]=(xMax-xMin)/3./%d;}\n", Dim[k],k,Dim[k],k,Dim[k]);
+         
+
+   if(logX)fprintf(outfile," double Xtext = xMin*pow(xMax/xMin,0.3);\n");  
+   else    fprintf(outfile," double Xtext = xMin+0.3*(xMax-xMin);\n");  
+   fprintf(outfile," double Ytext= yMax;\n");
+
+   if(logY)   
+   {
+     fprintf(outfile," Can->SetLogy();\n");
+     fprintf(outfile," double dYtext=pow(yMax/yMin,0.055);\n");
+   } else fprintf(outfile," double dYtext= (yMax-yMin)/15;\n");
+   
+       
+   fprintf(outfile," TH1F *hr = Can->DrawFrame(xMin,yMin,xMax,yMax);\n");
+   fprintf(outfile," hr->SetXTitle(\"%s\");\n",x_str);   
+   if(N==1) fprintf(outfile," hr->SetYTitle(\"%s\");\n",Y[0]);   
+
+   int maxDim=0;
+   for(k=0;k<N;k++) if(Dim[k]>maxDim) maxDim=Dim[k];
+   
+   for(k=0;k<N;k++)
+   {  
+     fprintf(outfile," double  Y%d[%d];\n",k,maxDim);
+     sprintf(format+strlen(format)," %%lf");
+     sprintf(read+strlen(read)," ,Y%d+i",k);
+     if(type[k]=='h')
+     {  fprintf(outfile," double  dY%d[%d];\n",k,maxDim);  
+        sprintf(format+strlen(format)," %%lf");
+        sprintf(read+strlen(read)," ,dY%d+i",k);
+     }
+   }
+   
+   fprintf(outfile, " FILE*f=fopen(\"%s\",\"r\");\n",fname);
+   fprintf(outfile, " for(int i=0;i<%d;)\n {\n",maxDim);
+   fprintf(outfile, "  fscanf(f,\"%%[^\\n]%%*c\",buff);\n");
+   fprintf(outfile, "  if(buff[0]!='#') {");
+   fprintf(outfile, "  sscanf(buff,\"%s\" %s); i++;", format, read);
+   fprintf(outfile, "    }\n }\n");
+   fprintf(outfile, " fclose(f);\n");
+
+//   fprintf(outfile, " double dX[%d];\n",dim);
+//   fprintf(outfile, " for(int i=0;i<%d;i++) dX[i]=(xMax-xMin)/%d/3.;\n",dim,dim);
+
+   fprintf(outfile, " TLatex ltx;\n");
+   fprintf(outfile, " ltx.SetTextFont(42);\n");
+   fprintf(outfile, " ltx.SetTextSize(0.04);\n");
+           
+   for(k=0;k<N;k++)
+   { if(type[k]=='h') 
+     {  fprintf(outfile,"   TGraphErrors *gr%d =new TGraphErrors(%d,X%d,Y%d,dX%d,dY%d);\n",k,Dim[k],k,k,k,k);
+        fprintf(outfile,"   gr%d->SetLineColor(%d);\n",k,k+1); 
+        fprintf(outfile,"   gr%d->Draw(\"P\");\n",k);
+     } else 
+     {   
+       fprintf(outfile, "   TGraph *gr%d = new TGraph (%d,X%d,Y%d);\n",k,Dim[k],k,k); 
+       fprintf(outfile, "   gr%d->SetLineColor(%d);\n",k,k+1);
+       if(type[k]=='l') fprintf(outfile, "   gr%d->Draw(\"L\");\n",k);
+       else fprintf(outfile, "   gr%d->Draw(\"C\");\n",k);
+     }
+     if(N>1 && Y[k][0])
+     {
+        if(logY) fprintf(outfile,"   Ytext/=dYtext;\n"); else  fprintf(outfile,"  Ytext-=dYtext;\n");
+/*
+        fprintf(outfile,"  TText *t%d = new TText(Xtext,Ytext,\"%s\");\n",k,Y[k]);
+        fprintf(outfile,"  t%d->SetTextColor(%d);\n",k,k+1);
+        fprintf(outfile,"  t%d->SetTextFont(42);\n",k);
+        fprintf(outfile,"  t%d->SetTextSize(0.03);\n",k);
+        fprintf(outfile,"  t%d->Draw();\n",k);
+*/        
+        fprintf(outfile,"    ltx.SetTextColor(%d);\n",k+1);
+        fprintf(outfile,"    ltx.DrawLatex(Xtext,Ytext,\"%s\");\n",Y[k]);         
+     } 
+   }  
+   fprintf(outfile," Can->Print(\"%s.pdf\");\n",basename);
+   
+   fprintf(outfile,"}\n");
+#endif   
+   fclose(outfile);
+   
+   messanykey(10,12,filename);
+}
+
+
+
 
 static void  writeROOT2D(char *fname,  double xMin,double xMax, double yMin, double yMax,
      int dimX, int dimY, char*x_str,char*y_str,char*upstr)   
@@ -1035,7 +1312,7 @@ int  plot_Nar( char*file, char*  title, double xMin, double xMax, char*xName, in
   double      ymin, ymax;
   char        f_name[STRSIZ], menustr[STRSIZ], buff[STRSIZ];
   char * type=malloc(sizeof(char)*N);
-  static int mouseXY=1;
+  static int mouseXY=0;
   
   for(i=0;i<N;i++) 
   {            for(k=0;k<Dim[i];k++) if(!isfinite( f[i][k])) return 1;
@@ -1060,7 +1337,7 @@ int  plot_Nar( char*file, char*  title, double xMin, double xMax, char*xName, in
    ymax=grafminmax.ymax;
    
    logX=xScale;
-   logScale=0;//(ymin >0 && grafminmax.ymax/grafminmax.ymin >10);   
+   logY=0;//(ymin >0 && grafminmax.ymax/grafminmax.ymin >10);   
    k = 0;      
 REDRAW:
    nCol0=maxCol();
@@ -1073,7 +1350,7 @@ REDRAW:
    {   fColor=colList[i];
        if(ff[i]) plot_hist(xMin,xMax,Dim[i],f[i],ff[i]); 
           else  if( type[i]=='l') plot_curve(xMin,xMax,Dim[i],f[i]);
-          else  plot_spline(xMin,xMax,Dim[i],xScale,f[i]);
+          else  plot_spline(xMin,xMax,Dim[i],f[i]);
    }                    
    tg_settextjustify(BottomText,LeftText);
    scrcolor(Red,bkcolor);
@@ -1102,7 +1379,7 @@ REDRAW:
             i= log(x/xMin)/h;
             i0=log(x/xMin)/h -0.5;
             if(i0<0) i0=0; if(i0>=Dim[k]-1) i0=Dim[k]-2;
-            x0=xMin*exp(h*(0.5+i0*h));
+            x0=xMin*exp(h*(0.5+i0));
             al=log(x/x0)/h;
           }else
           {
@@ -1127,7 +1404,7 @@ REDRAW:
    {  char sScale[20];
       void * pscr = NULL;
 
-      if(logScale) strcpy(sScale,"Log.   "); else strcpy(sScale,"Lin.   ");  
+      if(logY) strcpy(sScale,"Log.   "); else strcpy(sScale,"Lin.   ");  
    
       sprintf(menustr,"%c Y-max = %-9.3G Y-min = %-9.3G Y-scale = %s"
       " Spline           "
@@ -1146,21 +1423,21 @@ REDRAW:
            case 2:
              correctDouble(33,11,"Y-min = ",&grafminmax.ymin,1 );
              break;
-           case 3:  logScale=!logScale; break;
+           case 3:  logY=!logY; break;
            case 4: 
-           {  char * splineMenu=malloc((2+N*24)*sizeof(char));
+           {  char * splineMenu=malloc((2+N*30)*sizeof(char));
               int m=1;
-              splineMenu[0]=24;
+              splineMenu[0]=30;
               for(;;)
               { int l=0; 
                 splineMenu[1]=0;
                 for(i=0;i<N;i++)
-                { if(type[i]=='l')sprintf(splineMenu+strlen(splineMenu)," %-19.19s OFF",Y[i]);
-                  if(type[i]=='s')sprintf(splineMenu+strlen(splineMenu)," %-19.19s ON ",Y[i]);           
+                { if(type[i]=='l')sprintf(splineMenu+strlen(splineMenu)," %-25.25s OFF",Y[i]);
+                  if(type[i]=='s')sprintf(splineMenu+strlen(splineMenu)," %-25.25s ON ",Y[i]);           
                 }               
                 if(strlen(splineMenu)>1)
                 {             
-                  menu1(nCol0-26, 6, "Spline for",splineMenu,"",NULL,&m);
+                  menu1(nCol0-32, 6, "Spline for",splineMenu,"",NULL,&m);
                   if(m==0) break;
 
                   for(i=0,l=0; ;l++,i++) { if(type[i]=='h')i++;  if(l==m-1) break;  }
@@ -1188,7 +1465,7 @@ REDRAW:
                 nextFileName(baseF,"plot_",".tab");
                 correctStr(10,17,"File name: ",baseF,29,1);
                 trim(baseF);
-                err=writetable1(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,logScale,
+                err=writetable1(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
                     xName,title,N, Dim, f,ff,Y);
                 if(err) 
                 {         
@@ -1199,9 +1476,10 @@ REDRAW:
              }
                    
              char  fileMenu[]="\011"
-             " PAW     "
              " Root    "
+             " PAW     "
              " Gnuplot "
+             " Python  "
 //             " Math    "
               ;
              int m=1;
@@ -1210,14 +1488,17 @@ contin:
              while(m)
              {  menu1(nCol0-15, 6, "For Package",fileMenu,"n_graph_*",NULL,&m);             
                 switch(m)        
-                {  case 1: writePAW(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,logScale,
+                {  case 1: writeROOT(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
+                                    xName,title,N,Dim,type,Y);
+                   break;
+                   case 2: writePAW(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
                                     xName,title,N,Dim,type,Y);
                    break;                  
-                   case 2: writeROOT(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,logScale,
+                   case 3: writeGNU(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,           
                                     xName,title,N,Dim,type,Y);
-                   break;          
-                   case 3: writeGNU(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,logScale,           
+                   case 4: writePython(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
                                     xName,title,N,Dim,type,Y);
+                                                       
                    break;
 //                   case 4:
 //                     writeMath1(baseF,xMin,xMax,dim,f[0],ff[0],title,xName,Y[0]);  
@@ -1231,15 +1512,15 @@ contin:
              { messanykey(10,10," Wrong Y-range");
                break;
              } 
-             if(logScale && (grafminmax.ymax <=0)) 
+             if(logY && (grafminmax.ymax <=0)) 
              {  messanykey(10,10," Can not implement log_Y scale because Ymax<0");
-                logScale = 0;
+                logY = 0;
              }
                  
-             if(logScale && (grafminmax.ymin <=0)) grafminmax.ymin=grafminmax.ymax*1E-4;
+             if(logY && (grafminmax.ymin <=0)) grafminmax.ymin=grafminmax.ymax*1E-4;
              
               
-             if(logScale &&  grafminmax.ymax/grafminmax.ymin <=10 ) grafminmax.ymin=grafminmax.ymax/10.;
+             if(logY &&  grafminmax.ymax/grafminmax.ymin <=10 ) grafminmax.ymin=grafminmax.ymax/10.;
                             
              goto REDRAW;
       }   
@@ -1299,7 +1580,7 @@ void plot_2D(double hMin1,double hMax1,int nBin1,double hMin2,double hMax2,int n
   void *     prtscr;
   double     P=1;
 
-   logScale = 0;
+   logY = 0;
    logX=0;
    get_text(1,1,maxCol(),maxRow(),&prtscr);
 
