@@ -48,14 +48,14 @@ extern void  delpoly(poly  * p);
 extern poly  plusone(void);
 extern poly  copypoly(poly  p);
 extern void  sewpoly(poly  * p1,	poly  * p2);
-extern void  multpolyint(poly     * p, long    i);
+extern void  multpolyint(poly     * p,  NUM_TYPE i);
 extern poly  multtwopoly(poly  q1, poly  q2);
 extern poly  scalarmult(int  p1,	int  p2);
 extern void  assignsclmult(int  p1,	int  p2,	poly      p);
 extern void  deltensor(tensor  * t);
 extern tensor  copytens(tensor  t);
 extern void  sewtens(tensor * t1,tensor *t2);
-extern void  multtensint(tensor    * t,	long i);
+extern void  multtensint(tensor    * t,	NUM_TYPE i);
 extern void  multtensComplexpoly(tensor* t,poly re,poly im);
 extern void  multtenspoly(tensor  * t,  poly  p);
 extern void (*memoryInfo) (int);
