@@ -2,7 +2,6 @@
  Copyright (C) 1997, Alexander Pukhov, e-mail pukhov@theory.npi.msu.su
 */
 
-#include "tptcmac.h"
 #include "syst2.h"
 #include "process.h"
 #include "physics.h"
@@ -11,7 +10,7 @@
 vcsect     vcs;
 
 
-unsigned    subproc_f, subproc_sq;
+int    subproc_f, subproc_sq;
 
 char  modelmenu[STRSIZ];
 int   maxmodel;
