@@ -12,6 +12,7 @@
 whohow     liminsp, LimQ;
 whohow     limout;
 
+int ZWmax=1000, ZWmin=-1000;
 
 int  nin, nout, n_x;   /* Number of X-particles */
 shortstr  processch="";
@@ -346,17 +347,17 @@ do{
        forQ=0;
        sscanf(items[m],"%[^,]",frgm);
              
-      if(n=strstr(frgm,"!="))       
+      if((n=strstr(frgm,"!=")))       
       { if(!anti) {errTxt="wrong restriction"; break;}
         if(sscanf(n+2,"%d",&k)!=1) {errTxt="wrong number"; break;}
         else  { n[0]=0; k++; forQ=1;}
       }
-      else if(n=strstr(frgm,"<"))
+      else if((n=strstr(frgm,"<")))
       { if(!anti) {errTxt="wrong restriction"; break;}
         if(sscanf(n+1,"%d",&k)!=1) {errTxt="wrong number"; break;}
         else {n[0]=0; k=-k-1;}
       }
-      else if(n=strstr(frgm,">"))
+      else if((n=strstr(frgm,">")))
       {
         if(sscanf(n+1,"%d",&k)!=1) {errTxt="wrong number"; break;}
         else {n[0]=0;k++;}
@@ -364,6 +365,13 @@ do{
       else k=1;
       trim(frgm);
 
+      if(strcmp(frgm,"%Z+W")==0)
+      {  
+         if(k>0) ZWmax=k-1;
+         if(k<0) ZWmin=-k-1;
+         continue;
+      }
+                                             
       locateinbase(frgm,&j);
       if ((j == 0) || (!anti&&pseudop(j)))
       {  errTxt="wrong limit statement";
@@ -398,6 +406,8 @@ int enter(void)
 
    int curh=0;
 
+   ZWmax= 1000;
+   ZWmin=-1000;
 
    prtcllist(0);
    scrcolor(Red,BGmain);
