@@ -384,7 +384,7 @@ static int  readvars(int  check)
          
    setPub=1;   
    testingVar=nmodelvar;
-   for(i=nmodelvar; i>nCommonVars; i--) if(modelvars[i].pub==-1) 
+   for(i=nmodelvar; i>nCommonVars; i--) if(modelvars[i].pub) 
    {  readExpression(modelvars[i].func,rd_33, act_33,NULL);
       modelvars[i].pub=1;
    }   
@@ -1289,15 +1289,21 @@ int  loadModel(int check,int ugForce)
 }
 
 int  readModelFiles(char * path,int l)
-{  char fname[100];
+{  char fname[200];
    char *ext[5]={"vars","func","prtcls","lgrng","extlib"};
    int i;
        
    ldModelStatus=0; 
    sprintf(fname,"%s/%s%d.mdl",path,ext[4],l);
    if(access(fname,R_OK)) 
-   { FILE *f=fopen(fname,"w");
-     fprintf(f,"Any Model\n");
+   { char fname_var[200];
+     char tytle[200];
+     sprintf(fname_var,"%s/%s%d.mdl",path,ext[0],l);
+     FILE *f=fopen(fname_var,"r");
+     fscanf(f,"%[^\n]",tytle);
+     fclose(f);
+     f=fopen(fname,"w");
+     fprintf(f,"%s\n",tytle);
      fprintf(f,"Libraries\n");
      fprintf(f,"External libraries and  function prototypes                             <|\n");
      fprintf(f,"========================================================================\n");
