@@ -352,7 +352,20 @@ label_31:
                    { int err=rd_menu(1,k,process,&ndel,&ncalc,&nrest,&recpos);
                      if(!err) break;
                      trim(process);
-                     fprintf(f,"%s\n",process);
+                     if(nin==1)fprintf(f,"%s\n",process);
+                     else
+                     { char name1[20], name2[20];
+                       int pos;
+                       sscanf(process,"%[^,],%s",name1,name2); 
+                       trim(name1);trim(name2);
+                       fprintf(f,"%s",name1);
+                       locateinbase(name1,&pos);
+                       if(polarized(1,pos)) fprintf(f,"%%");
+                       fprintf(f,",%s",name2);
+                       locateinbase(name2,&pos);
+                       if(polarized(2,pos)) fprintf(f,"%%");  
+                       fprintf(f," %s\n",strstr(process,"->")); 
+                     } 
                    } 
                    fclose(f);
                    fclose(menup);
@@ -564,7 +577,7 @@ label_50:
              if(nPROCSS)
              { chdir("results"); 
                 makeVandP(0,"../models",n_model,2,pathtocalchep);
-               pCompile();
+               pCompile();               
                if(access("./n_calchep",X_OK)==0)
                { 
                   fflush(NULL); 
